# Script 7.1 - wood.rb

# A class for representing collections of wood.
class Wood

  # Read access for the boards array:
  attr_reader :boards

  # Constructor can initialize the @boards array.
  def initialize(*args)
    @boards = args
  end
  
  # Method for adding a single board.
  def add_board(board)
    @boards.push(board)
  end
  
  # Method for returning the total board feet.
  def total
    t = 0
    @boards.each { |b| t += (b[:width] * b[:length]) }
    t
  end
  
  # Method for seeing if enough wood is available
  # for a given project.
  def enough?(project)
    project.total <= self.total
  end
  
  # Addition operator:
  def +(rh)
  	@boards += rh.boards
  	self
  end
  
  # Equality operator:
  def ==(rh)
  	self.total == rh.total
  end
  
  # Identity operator:
  def ===(rh)
    @boards == rh.boards
  end
  
  # Comparison operator:
  def <=>(rh)
    if self.total < rh.total then -1
    elsif self.total > rh.total then 1
    else 0 end
  end
  
end # End of Wood class.

# Create a new Wood object:
maple = Wood.new({:width => 7, :length => 42}, {:width => 4.5, :length => 22}, {:width => 6.75, :length => 32.5}, {:width => 5, :length => 26.25})

# Create a second Wood object:
oak = Wood.new
oak.add_board({:width => 5, :length => 26.25})
oak.add_board({:width => 6.25, :length => 27.5})

# Some tests:
print "Total amount of maple: "
puts maple.total
print "Total amount of oak: "
puts oak.total
print "maple and oak are equal? "
puts maple == oak
print "maple compared to oak: "
puts maple <=> oak

# Buy more oak:
oak += Wood.new({:width => 7, :length => 19}, {:width => 5.5, :length => 22.2})

# Check a project:
table = Wood.new({:width => 4.5, :length => 22}, {:width => 6.75, :length => 32.5}, {:width => 5, :length => 26.25}, {:width => 5, :length => 26.25})
print "Board feet required to make a table: "
puts table.total
print "Do I have enough maple? "
puts maple.enough?(table) ? "It's a go!": "Sorry!"
print "Do I have enough oak? "
puts oak.enough?(table) ? "It's a go!": "Sorry!"
