# Script 8.4 - creditcard.rb

# Partial class for representing credit cards:
class CreditCard

  # Need getters for the balance and limit:
  attr_reader :balance, :limit
  
  # Protect the balance getter:
  protected :balance

  # Constructor sets the card's limit and balance:
  def initialize(limit, bal = 0)
    @limit = limit
    @balance = bal	
  end

  # For making charges:
  def charge(amt)
    # validation
    debit(amt)
  end

  # For making payments:
  def payment(amt)
    # validation
    credit(amt)
  end
  
  # Returns the difference between the limit and the balance:
  def available
    @limit - @balance
  end
  
  # Compares two objects by balance:
  def >(rh)
    return nil unless rh.respond_to?('balance')
	@balance > rh.balance
  end
  
  # Private methods impact the card's balance:
  private
  def debit(amt)
    @balance += amt
  end
  def credit(amt)
    @balance -= amt
  end
	
end # End of CreditCard class.

# Create two objects:
mc = CreditCard.new(2000)
visa = CreditCard.new(3000, 1200)

# Charge the card with the most available room:
if mc.available > visa.available then 
  mc.charge(225)
  puts "The MasterCard has been charged $225!"
else 
  visa.charge(225) 
  puts "The Visa has been charged $225!"
end

# Pay the card with the highest balance:
if mc > visa then 
  mc.payment(500)
  puts "Payment of $500 has been sent to the MasterCard!"
else 
  visa.payment(500) 
  puts "Payment of $500 has been sent to the Visa!"
end