# Script 14.2 - complete.rb

# Class for managing employees:
class Employees

  require 'rubygems'
  require 'Highline/import'
  require 'sqlite3'

  attr_reader :db

  # Constructor opens the database:
  def initialize(file)
    @db = SQLite3::Database.new(file)
    @db.results_as_hash = true
    @db.type_translation = true
    create_menu
  end
  
  # Method that creates the menu of options:
  def create_menu
    puts # Add some space
    # Create the menu:
    choose do |m|
      m.prompt = 'Select an option: '
      m.choice(:'Add an Employee') { add_employee }
      m.choice(:'View All Employees') { view_employees }
      m.choice(:'Exit') { exit_app }
    end
  end # End of create_menu

  # Method for adding employees:
  def add_employee
    puts # Add some space
    first_name = ask('First name? ') { |q| q.validate = /\A[a-z ,.'-]+\Z/i }
    last_name = ask('Last name? ') { |q| q.validate = /\A[a-z ,.'-]+\Z/i }
    id = ask('Employee ID? ', Integer) { |q| q.above = 0 }
    @db.execute('INSERT INTO employees (id, first_name, last_name) VALUES (?, ?, ?)', id, first_name, last_name)
    puts 'The employee has been added!' if @db.changes == 1
    create_menu
  end # End of add_employee
  
  # Method for returning records:
  def view_employees
    puts # Add some space
	puts "Current Employees"
  
    @db.execute('SELECT * FROM employees ORDER BY last_name') do |row|
      puts "#{row['id'].to_i}. #{row['last_name']}, #{row['first_name']}"    
    end

    create_menu
  end
  
  # Method for closing the application:
  def exit_app
    @db.close
    Process.exit
  end
  
end # End of Employees class.

# Create the object:
e = Employees.new('employees.db')